#
# spec file for package remmina
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define realver 1.2.0-rcgit.27
%bcond_with nx
Name:           remmina
Version:        1.2.0~rcgit.27
Release:        lp150.1.4
Summary:        Versatile Remote Desktop Client
License:        GPL-2.0+
Group:          Productivity/Networking/Other
URL:            http://www.remmina.org/
Source0:        https://github.com/FreeRDP/Remmina/archive/v%{realver}.tar.gz#/Remmina-%{realver}.tar.gz
# PATCH-FIX-UPSTREAM 644cd140a387c7b5d3805b8af9554e241d5d2954.patch github#FreeRDP/Remmina#1476 jweberhofer@weberhofer.at -- Fix compilation on factory
Patch0:         644cd140a387c7b5d3805b8af9554e241d5d2954.patch
BuildRequires:  cmake
BuildRequires:  ed
BuildRequires:  intltool
BuildRequires:  libgcrypt-devel
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(avahi-glib)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(freerdp2)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libssh)
BuildRequires:  pkgconfig(libvncserver)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(spice-client-gtk-3.0)
BuildRequires:  pkgconfig(telepathy-glib)
BuildRequires:  pkgconfig(vte-2.91)
BuildRequires:  pkgconfig(winpr2)
BuildRequires:  pkgconfig(xkbfile)
Recommends:     %{name}-lang
Recommends:     %{name}-plugin-rdp
Recommends:     %{name}-plugin-secret
Recommends:     %{name}-plugin-vnc
Provides:       %{name}-plugins-common = %{version}
Obsoletes:      %{name}-plugins-common < 1.0.0
%if 0%{?suse_version} > 1500
BuildRequires:  pkgconfig(wayland-client)
%endif
%if 0%{?is_opensuse}
BuildRequires:  pkgconfig(appindicator3-0.1)
%endif

%description
Remmina is a remote desktop client written in GTK+, aiming to be useful for
system administrators and travellers, who need to work with lots of remote
computers in front of either large monitors or tiny netbooks. Remmina supports
multiple network protocols such as RDP, VNC, NX, XDMCP and SSH via separate
plugins in an integrated and consistant user interface.

%package devel
Summary:        Development Files for %{name}
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}

%description devel
This package contains header files needed for developing plugins for
Remmina.

%package plugin-exec
Summary:        Plugin for Remmina to allow execution of local commands
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-exec
This package provides a plugin for Remmina allowing the execution of
local commands.

%package plugin-spice
Summary:        SPICE Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-spice
This package provides the SPICE protocol plugin for Remmina.

%package plugin-xdmcp
Summary:        XDMCP Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-xdmcp
This package provides the XDMCP protocol plugin for Remmina.

%if %{with nx}
%package plugin-nx
Summary:        NX Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       NX
Requires:       remmina = %{version}

%description plugin-nx
This package provides the NX protocol plugin for Remmina.
%endif

%package plugin-rdp
Summary:        RDP Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       freerdp
Requires:       remmina = %{version}

%description plugin-rdp
This package provides the RDP protocol plugin for Remmina.

%package plugin-vnc
Summary:        VNC Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-vnc
This package provides the RDP protocol plugin for Remmina.

#%%package plugin-telepathy
#Summary:        Telepathy Protocol Plugin for Remmina
#Group:          Productivity/Networking/Other
#Requires:       remmina = %%{version}

#%%description plugin-telepathy
#This package provides the Telepathy plugin for Remmina.

%package plugin-secret
Summary:        Gnome Keyring Pasword Manager Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}
Provides:       remmina-plugins-gnome = %{version}
Obsoletes:      remmina-plugins-gnome < %{version}

%description plugin-secret
This package provides a Remmina plugin for the GNOME keyring password manager.

%lang_package

%prep
%setup -q -n Remmina-%{realver}
%patch0 -p1

%build
#TODO: enable TELEPATHY when issues have been fixed
%if 0%{?is_opensuse}
%cmake -DWITH_TELEPATHY=OFF
%else
%cmake -DWITH_TELEPATHY=OFF -DWITH_APPINDICATOR=OFF
%endif

make %{?_smp_mflags}

%install
%cmake_install

%if %{without nx}
rm -f %{buildroot}%{_libdir}/remmina/plugins/remmina-plugin-nx.so \
    %{buildroot}%{_datadir}/icons/hicolor/*/emblems/remmina-nx.png
%endif

%suse_update_desktop_file org.remmina.Remmina Network RemoteAccess GTK

%find_lang %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post plugin-exec
%icon_theme_cache_post

%postun plugin-exec
%icon_theme_cache_postun

%post plugin-spice
%icon_theme_cache_post

%postun plugin-spice
%icon_theme_cache_postun

%post plugin-xdmcp
%icon_theme_cache_post

%postun plugin-xdmcp
%icon_theme_cache_postun

%if %{with nx}
%post plugin-nx
%icon_theme_cache_post

%postun plugin-nx
%icon_theme_cache_postun
%endif

%post plugin-rdp
%icon_theme_cache_post

%postun plugin-rdp
%icon_theme_cache_postun

%post  plugin-vnc
%icon_theme_cache_post

%postun plugin-vnc
%icon_theme_cache_postun

#%%post plugin-telepathy
#%%icon_theme_cache_post

#%%postun plugin-telepathy
#%%icon_theme_cache_postun

%files
%doc AUTHORS CHANGELOG.md LICENSE LICENSE.OpenSSL README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}-file.desktop
%{_datadir}/applications/org.remmina.Remmina.desktop
%{_datadir}/icons/hicolor/*/actions/*
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/icons/hicolor/*/emblems/remmina-sftp.png
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.remmina.Remmina.appdata.xml
%{_datadir}/mime/packages/%{name}-mime.xml
%{_datadir}/%{name}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins/
%{_mandir}/man1/%{name}.1%{ext_man}

%files lang -f %{name}.lang

%files devel
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc

%files plugin-exec
%{_libdir}/remmina/plugins/remmina-plugin-exec.so
%{_datadir}/icons/hicolor/*/emblems/remmina-tool.png

%files plugin-spice
%{_libdir}/remmina/plugins/remmina-plugin-spice.so
%{_datadir}/icons/hicolor/*/emblems/remmina-spice.png

%files plugin-xdmcp
%{_libdir}/remmina/plugins/remmina-plugin-xdmcp.so
%{_datadir}/icons/hicolor/*/emblems/remmina-xdmcp-ssh.png
%{_datadir}/icons/hicolor/*/emblems/remmina-xdmcp.png

%if %{with nx}
%files plugin-nx
%{_libdir}/remmina/plugins/remmina-plugin-nx.so
%{_datadir}/icons/hicolor/*/emblems/remmina-nx.png
%endif

%files plugin-rdp
%{_libdir}/remmina/plugins/remmina-plugin-rdp.so
%{_datadir}/icons/hicolor/*/emblems/remmina-rdp-ssh.png
%{_datadir}/icons/hicolor/*/emblems/remmina-rdp.png

%files plugin-vnc
%{_libdir}/remmina/plugins/remmina-plugin-vnc.so
%{_datadir}/icons/hicolor/*/emblems/remmina-vnc-ssh.png
%{_datadir}/icons/hicolor/*/emblems/remmina-vnc.png

#%%files plugin-telepathy
#%%defattr(-,root,root)
#%%{_libdir}/remmina/plugins/remmina-plugin-telepathy.so

%files plugin-secret
%{_libdir}/remmina/plugins/remmina-plugin-secret.so

%changelog
* Fri Feb 16 2018 jweberhofer@weberhofer.at
- Fix compilation on factory: upstream fix 644cd140a387c7b5d3805b8af9554e241d5d2954.patch
  for github#FreeRDP/Remmina#1476
* Thu Feb 15 2018 jweberhofer@weberhofer.at
- Updated dependencies
- Upgraded to 1.2.0-rcgit.27
  Implemented enhancements:
  * Remmina usage statistics collection
  * Remmina stats: Profiles and protocols counter
  * Updated freerdp on flatpak definition file
  Fixed bugs:
  * RDP + DYNRES: Screen is black immediately after connection and becames
    visible only later when DISP_DVC_CHANNEL_NAME is connected
  Other improvements:
  * Add initial [MS-RDPEGFX] software support
  * Permit SCALE_MODE_DYNRES before DISP_DVC_CHANNEL_NAME is enabled.
* Fri Jan  5 2018 jweberhofer@weberhofer.at
- Rename the plugin 'remmina-plugins-gnome' in 'remmina-plugin-secret'
- Added remmina-plugin-exec which allows execution of local commands
- Upgraded to 1.2.0-rcgit.26
  Implemented enhancements:
  * Allow external commands without protocols in create connection dialog
  * Option to completely hide the floating toolbar when in fullscreen.
  * Option to run Pre Command before ANYTHING else
  * Rename the plugin 'remmina-plugins-gnome' in 'remmina-plugins-secret'
  * Variables for pre- and post-commands
  * Implement an exec protocol plugin
  * Add SPICE Native WebDAV shared folder support
  * Added encryption algorithms options for SSH
  * SSH tunnel and pre/post commands improvements
  * Prior commands improvements
  * Add avahi host discovery for ssh and sftp plugins
  Fixed bugs:
  * Un-check of "Fullscreen on the same monitor as the connection window" won't save
  * Remmina resets screen resolution settings in RDP shortcut
  * SSH Tunneling is broken with SSH Agent with public key
  * Align SFTP and SSH plugins authentication and tunnel functionalities.
  * ssh_userauth_publickey_auto: should accept empty passphrase
  * Un-check of 'Fullscreen on the same monitor'
  Other improvements:
  * Updated translations
  * Fixed typos
  * Remove a couple of legacy "resolution" fields
* Thu Oct 26 2017 jweberhofer@weberhofer.at
- Upgraded to 1.2.0-rcgit.24
  Implemented enhancements:
  * Save SSH session to file
  * snap: Use the new desktop, desktop-legacy and wayland interfaces
  * snap: add password-manager-service interface for gnome-keyring
  * vte no longer optional
  * Fix window state saving for remmina_connection_window and main window
  * Crashes when I try opening Preference
  * Resolution and Passwords Not Saving in Connection Profiles
  * Focus-out-event should call UNFOCUS plugin feature, fixes
  * Fix some memory leaks
- Bugfixes
* Thu Oct 12 2017 jweberhofer@weberhofer.at
- Upgraded to 1.2.0-rcgit.21
  Implemented enhancements:
  * Feature Request: Create custom Terminal Color Schemes for SSH #1235
  * Enter key doesn't "Connect" when in Edit menu and password field is in focus #1233
  * Feature request - Option - Floating Desktop Name [$5] #815
  * Don't close connection windows when main window is closed #785
  * File association for connections #485
  * Implementation of dynamic resolution update for RDP #1292 (giox069)
  * Shortcutkey viewonly #1289 (antenore)
  * Simplify pthreads library detection #1274 (jabl)
  * Custom Color schemes for SSH #1272 (antenore)
  * RDP client keyboard mapping with GTK3 #1265 (giox069)
  * Make building the VNC plugin optional #1263 (diogocp)
  Fixed bugs:
  * copy / paste and charset #1300
  * Changes user name ssh tunnel (vnc over ssh) do not save. #1255
  * SSH username ignored for Tunnels for RDP #1254
  * Can't Specify X :display for XDMCP. #1251
  * "Remember last view mode for each connection" not respected in v1.2.0-rcgit.19 #1247
  * Remmina always remember password #1224
  * Host key not working with SPICE plugin connected to KVM client. #1035
  * Shortcutkey viewonly #1289 (antenore)
  Merged pull requests:
  * Fix charset conversion in VNC clipboard #1303 (giox069)
  * Add support for application/x-remmina MIME type, fixes #485 #1299 (giox069)
  * Reverted the notfication for the floating toolbar #1297 (antenore)
  * Fixes for notifications #1294 (giox069)
  * Server name is notified to the user everytime we enter a tab #1290 (antenore)
  * Exit strategy for Gnome Shell 3.26 #1287 (giox069)
  * Fix gtk redrawing in RDP plugin #1286 (giox069)
  * Gtk deprecations #1285 (giox069)
  * Add Keywords entry #1277 (mfvescovi)
  * Runtime paths for AppImage #1271 (giox069)
  * Get ssh_username from remmina profile - fixes #1255 #1267 (antenore)
  * Better button labelling and new save button #1250 (antenore)
* Fri Sep  1 2017 jweberhofer@weberhofer.at
- Enhancements to upgrade to the new freerdp package
- Removed build dependency: pkgconfig(webkit2gtk-4.0)
- Added new build dependency: libappindicator3-devel
- Built-dependency freerdp2-devel and dependency to libfreerdp2 has been
  introduced to force switching to the new freerdp2 package
- Suggest installation of RDP and VNC plugins
- Don't include app-indicator on SLES
- Cleaned up spec
- Upgraded to 1.2.0-rcgit.20
  Implemented enhancements:
  * Enter key doesn't "Connect" when in Edit menu and password field is in focus #1233
  * Set Linux as the default terminal color scheme. Fixes #1238 #1243 (antenore)
  Fixed bugs:
  * Remmina crashes each time I use FTP transfer #1257
  * Problems with some color schemes #1225
  Closed issues:
  * Color on SSH terminal window being applied #1238
  * Tray applet closing when last window gets closed #1236
  * Systray icon closes when closing 'Main Window' or RDP connection #1229
  * SSH Tunneling is broken with SSH Agent with public key #1228
  * Missing icons after compiling latest Git release #1221
  * RDP quality settings not saved #1216
  * Cannot connect after upgrading Ubuntu to 16.04 #946
  Merged pull requests:
  * passphrase not yet used in sftp connection - closes #1257 #1259 (antenore)
  * Added ssh_agent in the list of authorized method, fixes #1228 #1246 (antenore)
  * Connect when pressing enter in the password field #1242 (antenore)
  * Fixed terminal color palettes #1240 (antenore)
  * French translation update and other po files update with new strings to be translated #1239 (DevDef)
  * SSH Kerberos GSSAPI Auth #1237 (giox069)
  * Enter key doesn't "Connect" when in Edit menu and password field is in focus - #1233 #1234 (erichoog)
  * Fix link for issue #367 #1232 (erichoog)
  * Change Status Icon availability for gnome 3.16 #1230 (giox069)
- Upgraded to 1.2.0-rcgit.19
  Implemented enhancements:
  * SSH tunneling does not work with RDP server redirection #1175
  * Enhancement - Another User connected to the server, forcing [...] pop-up #1141
  * RD Gateway Doesn't Support different username/password #933
  * the checkbox, 'Save SSH Password', greyed out. #708
  * RD Gateway authentication doesn't work #511
  * Allow the user to hide the toolbar inside a remmina connection window #413
  * Support for RDP Gateway #347
  * Ssh improvements #1196 (antenore)
  * Implementing separate user and password for RD Gateway #1193 (antenore)
  * RDP: remove server hostname DNS check #1190 (giox069)
  * Pressing Enter in the Domain entry of Auth dialog submits #1163 (iivorait)
  * Add server name to popup warning #1142 (antenore)
  * Add an option to completely disable the floating toolbar in fullscreen mode #1135 (transistor1)
  * The host key should not affect subsequent key operations #1132 (nanxiongchao)
  Fixed bugs:
  * Remmina profile editor scrolling is broken #1179
  * Graphical issues when using byobu/tmux #1151
  * I always got an error message "SSH public key has changed!" #1129
  * problem with tui interfaces in remmina #1076
  * test bounty source #1048
  * Importing rdp file not successful #1039
  * Implementing separate user and password for RD Gateway #1193 (antenore)
  Closed issues:
  * RDP to Win10 makes ToolBar clear #1209
  * Upgrading to 1.2 failed #1202
  * Multiple NICs #1188
  * "Public Key (Automatic)" option does not work with ed25519 keys #1187
  * Cannot connect to Windows 10 after Creators Update (1703) #1186
  * Crashing on Load: Segfault #1185
  * Files in mounted sharefolders become terrabytes big. #1174
  * compilation on Debian 9 #1165
  * Clipboard sync is not working #1164
  * File Transfers to Share Folder Crashing Remmina 1.2.0-rcgit-18 Each Try #1159
  * Segfault when using the host SMB sharefolder on Windows (from Linux client) #1157
  * Custom RDP settings? #1146
  * Missing icons in remote session toolbar #1136
  * Opacity for pop up tool bar is too see-through #1131
  * option to remove fullscreen toolbar completely #1128
  * SSH terminal doesn't work #1125
  * Start remmina with fixed language #1119
  * Remmina Next is Corrupting the Unity Desktop #1111
  * Remove systemd dependency #1100
  * Keyboard Events #1096
  * No move or resize terminal window #1087
  * Connection Timeout - vfprintf.c no such file or directory - Segfault #1080
  * SSH password can't save , terminal auto disconnection #1078
  * Remmina getting down when used ssh & mc #1075
  * Only stored passwords when connecting via RD-Gateway #922
  * VNC over SSH tunnel very slow #713
  * Domain/Username/Password database #711
  * Remmina RDP hangs after second certificate confirmation when using RD gateway #706
  * SSH agent forwarding, tunnels and other nice stuff #692
  * When I open a RDP connexion on Microsoft Windows PC, SSH Client display is messing #663
  * Remmina doesn't respect ssh config files... #235
  * SSH: missed check availability of PubkicKey Auth on remote host before asking passphrase #176
  Merged pull requests:
  * Fixes for the exit strategy #1219 (giox069)
  * Issues 785 966 #1214 (giox069)
  * Ssh protocol plugin implementation #1206 (antenore)
  * The multi password changer #1203 (giox069)
  * Fix snap issues #1200 (dfiloni)
  * Terminal functionalities to make Remmina behave correctly with ncurses #1198 (antenore)
  * Fix multiple typos of 'transfered' word #1173 (mfvescovi)
  * RDP plugin: add password expired message and update po files #1170 (giox069)
  * Remmina --full-version command line option #1169 (antenore)
  * snapcraft: use snap-preload to get dynamic access to /snap path #1161 (3v1n0)
  * Inproved CodeTriage and Bountysource buttons #1143 (weberhofer)
  * Cmake clean #1140 (antenore)
  * Give precedence to libfreerdp2 and winpr2 libs #1138 (antenore)
  * travis: build the snap for PRs in Debug mode #1130 (3v1n0)
  * snap: optionally push all the built snaps on PRs to transfer.sh #1126 (3v1n0)
  * Small English nit (fullscreen_on_auto) #1124 (lnicola)
  * Fix german translation #1120 (giox069)
* Sun Aug 20 2017 zaitor@opensuse.org
- Drop obsolete and unused pkgconfig(unique-1.0) BuildRequires.
* Fri May 12 2017 tchvatal@suse.com
- Version update to version 1.2.0.rcgit.18:
  * Various fixes around, see the upstream Changelog
* Sun Feb  5 2017 mailaender@opensuse.org
- move README.SUSE to https://en.opensuse.org/Remmina
- update to version 1.2.0.rcgit.17
* Mon Jun 13 2016 mailaender@opensuse.org
- update to version 1.2.0.rcgit.13 as freerdp 1.0 isn't available anymore
- dropped patches:
  * remmina-close-ssh-tunnel-on-disconnect.patch
  * remmina-fix-desktop-file.patch
  * remmina-fix-fullscreen-with-multiple-monitors.patch
  * remmina-fix-install-paths.patch
  * remmina-fix-linker-issue.patch
  * remmina-fix-scrolling-in-vnc-plugin.patch
  * remmina-fix-window-resize.patch
  * remmina-gtk-2-22-support.patch
  * remmina-remove-inline-libvncserver.patch
  * remmina-vte-2.91-support.patch
* Tue Oct 13 2015 dimstar@opensuse.org
- openSUSE_Leap 42.1: also apply the patch for vte-2.91.
* Fri Sep  4 2015 dimstar@opensuse.org
- openSUSE Leap 42.1 (suse_version 1315) also has vte-2.91.
* Thu Jan 22 2015 gber@opensuse.org
- amend remmina-fix-install-paths.patch to fix the installation of
  headers (gh#FreeRDP/Remmina#292)
* Tue Oct  7 2014 gber@opensuse.org
- add remmina-vte-2.91-support.patch in order to support building
  against vte-2.91 for openSUSE >= 13.2
- rename README.SuSE to README.SUSE
* Tue Oct  7 2014 dmueller@suse.com
- fix build against Factory
* Sat Mar 23 2013 gber@opensuse.org
- enable TLS-support in VNC plugin (bnc#804320)
- add remmina-fix-scrolling-in-vnc-plugin.patch which fixes
  scrolling in the VNC plugin (backport from upstream git)
- add remmina-close-ssh-tunnel-on-disconnect.patch in order to
  close SSH tunnels on disconnect and avoid freezing (backport from
  upstream git)
- remmina-fix-window-resize.patch which fixes resizing the window
  (backport from upstream git)
- add remmina-fix-fullscreen-with-multiple-monitors.patch which
  fixes fullscreen mode with multiple monitors (backport from
  upstream git)
* Thu Aug 23 2012 gber@opensuse.org
- add missing dependency on gnutls
* Sat Aug 18 2012 gber@opensuse.org
- added remmina-remove-inline-libvncserver.patch in order to remove
  the inline copy of libvncserver (backport from upstream git)
* Mon Apr  2 2012 gber@opensuse.org
- use original tarball name to fix download check
* Mon Apr  2 2012 gber@opensuse.org
- disable the NX plugin by default
* Wed Mar 28 2012 gber@opensuse.org
- added separare patch remmina-fix-install-paths.patch in order to
  fix the installation paths
- specfile cleanup
- removed remmina-plugins-common, now provided by the main package
- split off -lang subpackage
* Wed Mar 21 2012 gankov@opensuse.org
- rewrote spec for using cmake
- merged with remmina-plugins into one source package (upstream
  now diestributes a single tarball with plugins)
- update to version 1.0.0
  + Main program design and functionality:
  * Switch to the CMake build system
  * Refactoring of code style
  * Changing file name convention
  + RDP protocol related:
  * Support for FreeRDP 1.0
  * Support for RemoteFX
  * Support for Network Level Authentication
  * Added certificate validation prompt
- added remmina-fix-linker-issue.patch which fixes a linking issue
  (backport from upstream git)
- added remmina-fix-desktop-file.patch which fixes the installation
  of the .desktop file (backport from upstream git)
- added remmina-gtk-2-22-support.patch in order to build on
  openSUSE 11.4 with GTK 2.22 as upstream requires 2.24+
* Thu Sep 29 2011 gber@opensuse.org
- libunique1 is available on Factory so use it
- do not recommend non-existent remmina-plugins
- add a note about plugins
* Thu Sep 29 2011 gber@opensuse.org
- change the pkgconfig(libssh) dependency to libssh-devel in the
  - devel subpackage
* Thu Sep 22 2011 gber@opensuse.org
- cleanup
  + added license/copyright header
  + improved description/summary
  + use SPDX license abbreviation
  + removed %%clean section
  + use the correct macros to update the icon/desktop file cache in
    %%post/%%postun
  + use pkgconfig symbols unconditionally (this can be handled
    at the project level)
  + removed empty NEWS
* Fri Apr  8 2011 lijewski.stefan@gmail.com
- spec cleanup, prepare to move X11:RemoteDesktop
* Mon Feb  7 2011 gav@qsolution.ru
- Update to version 0.9.3
  + Integrate scrolled window and fullscreen view modes into one button
  + Remove quick connect menu and consolidate the feature with Connection->New
  menu.
* Fri Nov  5 2010 michal.smrz@opensuse.cz
- Update to version 0.8.3
- Edited BuildRequires and Requires to match web pages
* Mon Sep 27 2010 michal.smrz@opensuse.cz
- merge with nilda package created by djs_core <admin@djscore.org>
* Mon Sep 27 2010 prusnak@opensuse.org
- spec cleanup
* Tue Sep 21 2010 lijewski.stefan@gmail.com
- initial package for openSUSE
